==> cxxtools_2.1.1.orig.tar.gz: cxxtools-2.1.1/src/clockimpl.h <==
/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "cxxtools/datetime.h"
#include "cxxtools/timespan.h"
#include <sys/time.h>
#include <time.h>

namespace cxxtools {

class ClockImpl
{
    public:
        ClockImpl();

        ~ClockImpl();

        void start ();

        Timespan stop();

        static DateTime getSystemTime();

        static DateTime getLocalTime();

        static Timespan getSystemTicks();

    private:
        struct timeval  _startTime;
        struct timeval  _stopTime;
        struct timezone _timeZone;
};

} // namespace cxxtools

==> cxxtools_2.2.1.orig.tar.gz: cxxtools-2.2.1/src/clockimpl.h <==
/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "cxxtools/datetime.h"
#include "cxxtools/timespan.h"
#include <sys/time.h>
#include <time.h>
#include "config.h"

namespace cxxtools
{

class ClockImpl
{
    public:
        ClockImpl();

        ~ClockImpl();

        void start ();

        Timespan stop();

        static DateTime getSystemTime();

        static DateTime getLocalTime();

        static Timespan getSystemTicks();

    private:
#ifdef HAVE_CLOCK_GETTIME
        struct timespec  _startTime;
        struct timespec  _stopTime;
#else
        struct timeval  _startTime;
        struct timeval  _stopTime;
#endif
};

} // namespace cxxtools
